export interface IPagination {
    pageSize?: number;
    page?: number;
}
export declare type BaseBrowse = {
    pagination?: IPagination;
    sort?: any;
    speedMode?: boolean;
};
declare type Dict = {
    [k: string]: any;
};
declare type DictWithId = {
    id?: bigint;
    [k: string]: any;
};
declare type SelectWithId = {
    id?: boolean;
    [k: string]: any;
};
interface BasePrismaClient {
    findMany: (arg: {
        select?: SelectWithId | null;
        include?: Dict | null;
        where?: Dict;
        orderBy?: unknown;
        cursor?: Dict;
        take?: number;
        skip?: number;
        distinct?: unknown;
    }) => any;
    create: (arg: {
        select?: SelectWithId | null;
        include?: Dict | null;
        data: any;
    }) => any;
    update: (arg: {
        select?: SelectWithId | null;
        include?: Dict | null;
        data: any;
        where: DictWithId;
    }) => any;
    delete: (arg: {
        select?: SelectWithId | null;
        include?: Dict | null;
        where: DictWithId;
    }) => any;
    [k: string]: any;
}
export declare type FormatErrorHandler = (error: TypeError, modelName: string, fnName: string, args: any[]) => never;
export declare type FormatLogHandler<R> = (modelName: string, fnName: string, args: any[], retData: R) => string;
declare type BrowseOption = {
    scanAll?: boolean;
    sort?: object;
    speedMode?: boolean;
};
export declare abstract class BaseModel<PrismaClient extends BasePrismaClient, CustomCreateInput, WhereUniqueInput, WhereInput, CustomUpdateInput, R = unknown> {
    protected readonly prisma: PrismaClient;
    protected readonly modelName: string;
    protected readonly formatErrorHandler: FormatErrorHandler;
    protected readonly formatLogHandler: FormatLogHandler<R>;
    constructor(prisma: PrismaClient, formatErrorHandler: FormatErrorHandler, modelName: string, formatLogHandler?: FormatLogHandler<R>);
    add(input: CustomCreateInput, requestedBy: bigint): Promise<R>;
    read(where: WhereUniqueInput): Promise<R>;
    browse(pagination?: IPagination, where?: WhereInput, options?: BrowseOption): Promise<{
        items: R[];
        properties: {
            count?: number;
            pageSize?: number;
            page?: number;
        };
    }>;
    edit(input: CustomUpdateInput, where: WhereUniqueInput, requestedBy: bigint): Promise<R>;
    delete(where: WhereUniqueInput): Promise<R>;
    activate(where: WhereUniqueInput, requestedBy: bigint): Promise<R>;
    deactivate(where: WhereUniqueInput, requestedBy: bigint): Promise<R>;
}
export {};
